package com.usky.iot.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.usky.common.core.bean.CommonPage;
import com.usky.common.security.utils.SecurityUtils;
import com.usky.iot.domain.BaseGgpFacility;
import com.usky.iot.mapper.BaseGgpFacilityMapper;
import com.usky.iot.service.BaseGgpFacilityService;
import com.usky.common.mybatis.core.AbstractCrudService;
import com.usky.iot.service.vo.BaseGgpFacilityExportVo;
import com.usky.iot.service.vo.BaseGgpFacilityRequest;
import com.usky.system.model.LoginUser;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 地理信息 服务实现类
 * </p>
 *
 * @author han
 * @since 2023-06-02
 */
@Service
public class BaseGgpFacilityServiceImpl extends AbstractCrudService<BaseGgpFacilityMapper, BaseGgpFacility> implements BaseGgpFacilityService {
    @Override
    public boolean add(BaseGgpFacility baseGgpFacility) {
        baseGgpFacility.setCreator(SecurityUtils.getUsername());
        baseGgpFacility.setCreateTime(LocalDateTime.now());
        return this.save(baseGgpFacility);
    }

    @Override
    public void update(BaseGgpFacility baseGgpFacility) {
        baseGgpFacility.setUpdateTime(LocalDateTime.now());
        baseGgpFacility.setUpdatePerson(SecurityUtils.getUsername());
        this.updateById(baseGgpFacility);
    }

    @Override
    public CommonPage<BaseGgpFacility> page(BaseGgpFacilityRequest piRequest) {
        IPage<BaseGgpFacility> page = new Page<>(piRequest.getCurrent(), piRequest.getSize());
        LambdaQueryWrapper<BaseGgpFacility> lambdaQuery = Wrappers.lambdaQuery();
        lambdaQuery
                .like(StringUtils.isNotBlank(piRequest.getFacilityName()),BaseGgpFacility::getFacilityName,
                        piRequest.getFacilityName())
                .eq(StringUtils.isNotBlank(piRequest.getFacilityNum()),BaseGgpFacility::getFacilityNum,piRequest.getFacilityNum())
                .eq(null != piRequest.getFacilityType(),BaseGgpFacility::getFacilityType,piRequest.getFacilityType())
                .eq(null != piRequest.getId(),BaseGgpFacility::getId,piRequest.getId())
                .eq(BaseGgpFacility::getTenantId, SecurityUtils.getTenantId())
                .orderByDesc(BaseGgpFacility::getId);
        page = this.page(page,lambdaQuery);
        return new CommonPage<>(page.getRecords(),page.getTotal(),page.getCurrent(),page.getSize());
    }

    @Override
    public boolean remove(Integer id) {
        return this.removeById(id);
    }

    @Override
    public List<BaseGgpFacilityExportVo> recordLsitExport(BaseGgpFacilityRequest exRequest) {
        DateTimeFormatter df = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");
        LoginUser loginUser = SecurityUtils.getLoginUser();
        String userType = null;
        if (loginUser != null && !"".equals(loginUser)) {
            userType = loginUser.getUserType();
        }
        LambdaQueryWrapper<BaseGgpFacility> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(BaseGgpFacility::getTenantId, SecurityUtils.getTenantId())
                .like(StringUtils.isNotBlank(exRequest.getFacilityName()), BaseGgpFacility::getFacilityName, exRequest.getFacilityName())
                .eq(StringUtils.isNotBlank(exRequest.getFacilityNum()), BaseGgpFacility::getFacilityNum, exRequest.getFacilityNum())
                .eq(null != exRequest.getFacilityType(),BaseGgpFacility::getFacilityType,exRequest.getFacilityType())
                .orderByDesc(BaseGgpFacility::getId);
        List<BaseGgpFacility> baseGgpFacilityList = this.list(queryWrapper);
        List<BaseGgpFacilityExportVo> list = new ArrayList<>();
        for (int i = 0; i < baseGgpFacilityList.size(); i++) {
            BaseGgpFacilityExportVo baseGgpFacilityExportVo = new BaseGgpFacilityExportVo();
            baseGgpFacilityExportVo.setXh(i + 1);
            baseGgpFacilityExportVo.setId(baseGgpFacilityList.get(i).getId());
            baseGgpFacilityExportVo.setFacilityNum(baseGgpFacilityList.get(i).getFacilityNum());
            baseGgpFacilityExportVo.setFacilityType(baseGgpFacilityList.get(i).getFacilityType());
            baseGgpFacilityExportVo.setFacilityName(baseGgpFacilityList.get(i).getFacilityName());
            baseGgpFacilityExportVo.setAddress(baseGgpFacilityList.get(i).getAddress());
            baseGgpFacilityExportVo.setImagesUrl(baseGgpFacilityList.get(i).getImagesUrl());
            baseGgpFacilityExportVo.setContact(baseGgpFacilityList.get(i).getContact());
            baseGgpFacilityExportVo.setContactPhone(baseGgpFacilityList.get(i).getContactPhone());
            baseGgpFacilityExportVo.setStatus(baseGgpFacilityList.get(i).getStatus());
            baseGgpFacilityExportVo.setCreateTime(baseGgpFacilityList.get(i).getCreateTime().format(df));
            list.add(baseGgpFacilityExportVo);
        }
        return list;
    }
}
